"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.crossLaunchCommand = exports.callbackLaunchCommand = void 0;
const api_1 = require("@raycast/api");
const read_pkg_up_1 = require("read-pkg-up");
const callbackLaunchCommand = async (options, result) => (0, api_1.launchCommand)({
    ...options,
    context: {
        ...options.context,
        ...result,
    },
});
exports.callbackLaunchCommand = callbackLaunchCommand;
const crossLaunchCommand = async (options, callbackLaunchOptions) => {
    if (callbackLaunchOptions === false) {
        return (0, api_1.launchCommand)(options);
    }
    // eslint-disable-next-line unicorn/prefer-module, @typescript-eslint/no-unsafe-assignment
    const pack = (0, read_pkg_up_1.sync)({ cwd: __dirname, normalize: false });
    const ownerOrAuthorName = (pack?.packageJson?.owner ??
        pack?.packageJson?.author);
    if ('ownerOrAuthorName' in options) {
        const targetHandle = `${options.ownerOrAuthorName}/${options.extensionName}`;
        // eslint-disable-next-line @typescript-eslint/no-unsafe-call
        if (!pack?.packageJson?.crossExtensions?.includes(targetHandle)) {
            const message = `Target extension '${targetHandle}' should be listed in 'crossExtensions' of package.json.`;
            console.error(message);
            return;
        }
    }
    return (0, api_1.launchCommand)({
        ...options,
        context: {
            ...options.context,
            callbackLaunchOptions: {
                name: api_1.environment.commandName,
                extensionName: api_1.environment.extensionName,
                ownerOrAuthorName,
                type: api_1.LaunchType.UserInitiated,
                ...callbackLaunchOptions,
            },
        },
    });
};
exports.crossLaunchCommand = crossLaunchCommand;
